@@ -1,50 +1,59 @@
-from typing import Optional, List, Type
+from typing import Optional, List, Type, Tuple
 
 import numpy as np
 from numpy import ndarray
 
-from skfem.mesh import Mesh
+from ..refdom import Refdom
 from .discrete_field import DiscreteField
 
 
-class Element():
-    """Finite element.
+class Element:
+    """Evaluate finite element basis.
+
+    This class should not be initialized directly.  Use different subclasses,
+    e.g.,
+
+    - :class:`ElementLineP1`
+    - :class:`ElementTriP1`
+    - :class:`ElementQuad1`
+    - :class:`ElementTetP1`
+    - :class:`ElementHex1`
 
     Attributes
     ----------
     nodal_dofs
-        Number of DOFs per node.
+        Number of DOFs per node.  Used within :class:`Basis` to define the
+        global DOF numbering.
     facet_dofs
-        Number of DOFs per facet.
+        Number of DOFs per facet.  Used within :class:`Basis` to define the
+        global DOF numbering.
     interior_dofs
-        Number of DOFs inside the element.
+        Number of DOFs inside the element.  Used within :class:`Basis` to
+        define the global DOF numbering.
     edge_dofs
-        Number of DOFs per edge.
+        Number of DOFs per edge.  Used within :class:`Basis` to define the
+        global DOF numbering.
     dim
         The spatial dimension.
     maxdeg
-        Polynomial degree of the basis. Used to calculate quadrature rules.
+        Polynomial degree of the basis.  Used within :class:`Basis` to
+        automatically find quadrature rules.
     dofnames
-        A list of strings that indicate DOF types. Different possibilities:
-        - 'u' indicates that it is the point value
-        - 'u^1' indicates the first vectorial component
-        - 'u^n' indicates the normal component
-        - 'u^t' indicates the tangential component
-        - 'u_x' indicates the derivative wrt x
-        - 'u_n' indicates the normal derivative
-        - ...
-    mesh_type
-        Mesh type for calculating number of edges, etc.
+        A list of strings indicating the DOF types. See :ref:`finddofs`.
 
     """
     nodal_dofs: int = 0
     facet_dofs: int = 0
     interior_dofs: int = 0
     edge_dofs: int = 0
-    dim: int = -1
     maxdeg: int = -1
     dofnames: List[str] = []
-    mesh_type: Type = Mesh
+    refdom: Type[Refdom] = Refdom
+    doflocs: ndarray
+
+    @property
+    def dim(self):
+        return self.refdom.dim()
 
     def orient(self, mapping, i, tind=None):
         """Orient basis functions. By default all = 1."""
@@ -57,7 +66,7 @@ class Element():
                mapping,
                X: ndarray,
                i: int,
-               tind: Optional[ndarray] = None) -> DiscreteField:
+               tind: Optional[ndarray] = None) -> Tuple[DiscreteField, ...]:
         """Evaluate the global basis functions, given local points X.
 
         The global points - at which the global basis is evaluated at - are
@@ -80,7 +89,7 @@ class Element():
 
         Returns
         -------
-        DiscreteField
+        Tuple[DiscreteField, ...]]
             The global basis function evaluted at the quadrature points.
 
         """
@@ -92,11 +101,9 @@ class Element():
 
     def _bfun_counts(self) -> ndarray:
         """Count number of nodal/edge/facet/interior basis functions."""
-        return np.array([self.nodal_dofs * self.mesh_type.t.shape[0],
-                         self.edge_dofs * self.mesh_type.t2e.shape[0]
-                         if hasattr(self.mesh_type, 'edges') else 0,
-                         self.facet_dofs * self.mesh_type.t2f.shape[0]
-                         if hasattr(self.mesh_type, 'facets') else 0,
+        return np.array([self.nodal_dofs * self.refdom.nnodes,
+                         self.edge_dofs * self.refdom.nedges,
+                         self.facet_dofs * self.refdom.nfacets,
                          self.interior_dofs])
 
     def __mul__(self, other):
@@ -107,11 +114,3 @@ class Element():
         b = other.elems if isinstance(other, ElementComposite) else [other]
 
         return ElementComposite(*a, *b)
-
-    @property
-    def refdom(self):
-        return self.mesh_type.refdom
-
-    @property
-    def brefdom(self):
-        return self.mesh_type.brefdom
