@@ -4,27 +4,27 @@ import numpy as np
 from numpy import ndarray
 
 from .element import Element
+from .discrete_field import DiscreteField
 
 
 class ElementComposite(Element):
     """Combine multiple elements.
 
-    Allows having different basis functions for different components of a
+    Allows using different basis functions for different components of a
     vectorial solution.
 
     """
 
-    def __init__(self, *elems):
+    def __init__(self, *elems: Element):
         self.elems = elems
         self.nodal_dofs = sum([e.nodal_dofs for e in self.elems])
         self.edge_dofs = sum([e.edge_dofs for e in self.elems])
         self.facet_dofs = sum([e.facet_dofs for e in self.elems])
         self.interior_dofs = sum([e.interior_dofs for e in self.elems])
         self.maxdeg = sum([e.maxdeg for e in self.elems])
-        self.dim = self.elems[0].dim
 
         for e in self.elems:
-            if e.mesh_type is not self.elems[0].mesh_type:
+            if e.refdom is not self.elems[0].refdom:
                 raise ValueError("Elements are incompatible.")
 
         dofnames = []
@@ -46,17 +46,23 @@ class ElementComposite(Element):
         self.dofnames = dofnames
 
         doflocs = []
-        for i in range(np.sum(np.array([e._bfun_counts()
-                                        for e in self.elems]))):
+        for i in np.arange(np.sum(np.array([e._bfun_counts()
+                                            for e in self.elems])),
+                           dtype=int):
             n, ind = self._deduce_bfun(i)
             doflocs.append(self.elems[n].doflocs[ind])
         self.doflocs = np.array(doflocs)
 
-        self.mesh_type = elems[0].mesh_type
+        self.refdom = elems[0].refdom
+
+    @property
+    def dim(self):
+        return self.elems[0].dim
 
     def _deduce_bfun(self, i: int):
         """Deduce component and basis function for i'th index."""
-        counts: ndarray = sum([e._bfun_counts() for e in self.elems])
+        counts = np.sum(np.array([e._bfun_counts()
+                                  for e in self.elems]), axis=0)
         tmp: List[Any] = []
         ns: List[Any] = []
         if counts[0] > 0:
@@ -81,18 +87,18 @@ class ElementComposite(Element):
         for j in range(len(self.elems)):
             maskj = mask == j
             total = np.sum(maskj)
-            seq = np.arange(total, dtype=np.int)
+            seq = np.arange(total, dtype=np.int_)
             inds[maskj] = seq
 
         return ns[i], inds[i]
 
     def gbasis(self, mapping, X: ndarray, i: int, tind=None):
+        """Call correct :meth:`Element.gbasis` based on ``i``."""
         n, ind = self._deduce_bfun(i)
-        output = []
+        output: List[DiscreteField] = []
         for k, e in enumerate(self.elems):
             if n == k:
                 output.append(e.gbasis(mapping, X, ind, tind)[0])
             else:
-                output.append(e.gbasis(mapping, X, 0, tind)[0]
-                              .zeros_like())
+                output.append(e.gbasis(mapping, X, 0, tind)[0].zeros_like())
         return tuple(output)
