@@ -1,23 +1,22 @@
 import numpy as np
 
-from ...mesh import MeshLine
 from ..element_h1 import ElementH1
+from ...refdom import RefLine
 
 
 class ElementLineP2(ElementH1):
 
     nodal_dofs = 1
     interior_dofs = 1
-    dim = 1
     maxdeg = 2
     dofnames = ['u', 'u']
     doflocs = np.array([[0.],
                         [1.],
                         [.5]])
-    mesh_type = MeshLine
+    refdom = RefLine
 
     def lbasis(self, X, i):
-        x = X[0, :]
+        x = X[0]
 
         if i == 0:
             phi = 1 - 3 * x + 2 * x ** 2
