@@ -1,20 +1,19 @@
 import numpy as np
 
 from ..element_h1 import ElementH1
-from ...mesh.mesh3d import MeshTet
+from ...refdom import RefTet
 
 
 class ElementTetCR(ElementH1):
 
     facet_dofs = 1
-    dim = 3
     maxdeg = 1
     dofnames = ['u']
     doflocs = np.array([[1 / 3, 1 / 3, 0.],
                         [1 / 3, 0., 1 / 3],
                         [0., 1 / 3, 1 / 3],
                         [1 / 3, 1 / 3, 1 / 3]])
-    mesh_type = MeshTet
+    refdom = RefTet
 
     def lbasis(self, X, i):
         x, y, z = X
