@@ -1,20 +1,19 @@
 import numpy as np
 
 from ..element_hdiv import ElementHdiv
-from ...mesh.mesh3d import MeshTet
+from ...refdom import RefTet
 
 
 class ElementTetRT0(ElementHdiv):
 
     facet_dofs = 1
-    dim = 3
     maxdeg = 1
     dofnames = ['u^n']
     doflocs = np.array([[.5, .5, .0],
                         [.5, .0, .5],
                         [.0, .5, .5],
                         [.5, .5, .5]])
-    mesh_type = MeshTet
+    refdom = RefTet
 
     def lbasis(self, X, i):
         x, y, z = X
