@@ -1,8 +1,10 @@
 from .element_tri_p1 import ElementTriP1  # noqa
 from .element_tri_p2 import ElementTriP2  # noqa
 from .element_tri_dg import ElementTriDG  # noqa
+from .element_tri_cr import ElementTriCR  # noqa
 from .element_tri_p0 import ElementTriP0  # noqa
 from .element_tri_rt0 import ElementTriRT0  # noqa
 from .element_tri_mini import ElementTriMini  # noqa
 from .element_tri_morley import ElementTriMorley  # noqa
 from .element_tri_argyris import ElementTriArgyris  # noqa
+from .element_tri_hermite import ElementTriHermite  # noqa
