@@ -1,11 +1,10 @@
-from ..element_h1 import ElementH1
-from ...mesh.mesh2d import MeshTri
+from ..element import Element
+from ...refdom import RefTri
 
 
-class ElementTriDG(ElementH1):
+class ElementTriDG(Element):
 
-    dim = 2
-    mesh_type = MeshTri
+    refdom = RefTri
 
     def __init__(self, elem):
         # change all dofs to interior dofs
@@ -17,5 +16,5 @@ class ElementTriDG(ElementH1):
         self.dofnames = elem.dofnames
         self.doflocs = elem.doflocs
 
-    def lbasis(self, X, i):
-        return self.elem.lbasis(X, i)
+    def gbasis(self, *args, **kwargs):
+        return self.elem.gbasis(*args, **kwargs)
