@@ -1,19 +1,18 @@
 import numpy as np
 
 from ..element_h1 import ElementH1
-from ...mesh.mesh2d import MeshTri
+from ...refdom import RefTri
 
 
 class ElementTriP1(ElementH1):
 
     nodal_dofs = 1
-    dim = 2
     maxdeg = 1
     dofnames = ['u']
     doflocs = np.array([[0., 0.],
                         [1., 0.],
                         [0., 1.]])
-    mesh_type = MeshTri
+    refdom = RefTri
 
     def lbasis(self, X, i):
         x, y = X
